def deg_to_direction(degree):
    position = 0
    directions = ['N', 'NE', 'E', 'SE', 'S', 'SW', 'W', 'NW']
    if degree > 330 or degree <= 30:
        position = 0
    elif degree > 30 or degree <= 60:
        position = 1
    elif degree > 60 or degree <= 120:
        position = 2
    elif degree > 120 or degree <= 150:
        position = 3
    elif degree > 150 or degree <= 210:
        position = 4
    elif degree > 210 or degree <= 240:
        position = 5
    elif degree > 240 or degree <= 300:
        position = 6
    elif degree > 300 or degree <= 330:
        position = 7
    return directions[position]


def moon_phase_to_string(phase):
    position = 0
    phases = ['New', 'Wax C', '1 Q H',
              'Wax G', 'Full', 'Wan G',
              'L Q H', 'Wan C']
    if phase == 0 or phase == 1:
        position = 0
    elif phase < .25:
        position = 1
    elif phase < .35:
        position = 2
    elif phase < .5:
        position = 3
    elif phase == .5:
        position = 4
    elif phase < .63:
        position = 5
    elif phase == .75:
        position = 6
    elif phase < 1:
        position = 7
    return phases[position]



import datetime
import json
import requests
import math

from openweatherclass.geodataclass import GeoDataClass
from openweatherclass.historydataclass import HistoricDataClass
from openweatherclass.weatherdataclass import WeatherDataClass

with open("openweatherclass/condition_codes.json", mode='r') as file:
    CONDITIONS_JSON = json.load(file)


class WeatherClass:

    def __init__(self, api_key, zipcode, units='metric'):
        self.API_KEY = api_key
        self.zipcode = zipcode
        self.units = units
        self.weather_data = WeatherDataClass
        self.geo_data = GeoDataClass
        self.historic_data = HistoricDataClass
        self.today_historic_data = HistoricDataClass
        self.condition_codes = CONDITIONS_JSON
        self.lat = 0
        self.lon = 0
        self.get_coordinates()
        self.get_weather()

    def get_coordinates(self):
        payload = {
            'zip': f"{self.zipcode}",
            'appid': self.API_KEY,
        }
        zip_request = requests.get(url='https://api.openweathermap.org/geo/1.0/zip', params=payload)
        zip_request.raise_for_status()
        self.geo_data = zip_request.json()
        self.lat = self.geo_data['lat']
        self.lon = self.geo_data['lon']

    def get_weather(self):
        payload = {
            "lat": self.lat,
            "lon": self.lon,
            "appid": self.API_KEY,
            "units": self.units
        }
        weather_request = requests.get(url='https://api.openweathermap.org/data/2.5/onecall', params=payload)
        weather_request.raise_for_status()
        self.weather_data = weather_request.json()

    def update_weather(self):
        self.get_weather()

    def get_historic_weather(self, day):
        dt = math.floor((datetime.datetime.today() - datetime.timedelta(days=day)).timestamp())
        payload = {
            "lat": self.lat,
            "lon": self.lon,
            "appid": self.API_KEY,
            "units": self.units,
            "dt": dt
        }
        weather_request = requests.get(url='https://api.openweathermap.org/data/2.5/onecall/timemachine',
                                       params=payload)
        weather_request.raise_for_status()
        self.historic_data = weather_request.json()

    def get_today_history(self):
        dt = math.floor((datetime.datetime.today() - datetime.timedelta(days=1)).timestamp())
        payload = {
            "lat": self.lat,
            "lon": self.lon,
            "appid": self.API_KEY,
            "units": self.units,
            "dt": dt
        }
        weather_request = requests.get(url='https://api.openweathermap.org/data/2.5/onecall/timemachine',
                                       params=payload)
        weather_request.raise_for_status()
        self.today_historic_data = weather_request.json()

    def check_condition(self, code):
        for codes in self.condition_codes:
            try:
                if codes['code'] == code:
                    return codes['description']
            except IndexError:
                print("Not Found.")



from __future__ import annotations
from typing import List, Optional
from pydantic import BaseModel


class WeatherItem(BaseModel):
    id: int
    main: str
    description: str
    icon: str


class Current(BaseModel):
    dt: int
    sunrise: int
    sunset: int
    temp: float
    feels_like: float
    pressure: int
    humidity: int
    dew_point: float
    uvi: float
    clouds: int
    visibility: int
    wind_speed: float
    wind_deg: int
    wind_gust: float
    weather: List[WeatherItem]


class WeatherItem1(BaseModel):
    id: int
    main: str
    description: str
    icon: str


class HourlyItem(BaseModel):
    dt: int
    temp: float
    feels_like: float
    pressure: int
    humidity: int
    dew_point: float
    uvi: float
    clouds: int
    visibility: int
    wind_speed: float
    wind_deg: int
    wind_gust: Optional[float] = None
    weather: List[WeatherItem1]


class HistoricDataClass(BaseModel):
    lat: float
    lon: float
    timezone: str
    timezone_offset: int
    current: Current
    hourly: List[HourlyItem]
